@@ -1,4 +1,4 @@
-pub struct Complex(u64, u64);
+pub struct Complex(pub u64, pub u64);
 
 #[cfg(test)]
 mod tests {
